@@ -1,4 +1,4 @@
-from enum import Enum, unique, auto
+from enum import Enum, auto, unique
 
 
 class StrEnum(str, Enum):
