@@ -25,7 +25,7 @@ class Inventory(list):
     owner_id: str
 
     def __init__(
-        self, *items: Item, assets=None, descriptions=None, steamid64: str = None
+        self, *items: Item, assets=None, descriptions=None, steamid64: str | None = None
     ):
         if assets and descriptions and steamid64:
             self.owner_id = steamid64
@@ -102,7 +102,9 @@ def get_inventory(steamid64: str) -> Inventory | None:
     """
     if not steamid64:
         return None
-    r = requests.get(f"https://steamcommunity.com/inventory/{steamid64}/730/2")
+    r = requests.get(
+        f"https://steamcommunity.com/inventory/{steamid64}/730/2?count=1500"
+    )
 
     if r.status_code == 200:
         json = r.json()
@@ -111,7 +113,7 @@ def get_inventory(steamid64: str) -> Inventory | None:
         return parse_inventory(json, steamid64)
     elif r.status_code == 403:
         raise InventoryIsPrivateException("The requested Inventory is private.")
-    elif r.status_code == 500:
+    elif r.status_code == 429:
         raise TooManyRequestsAtOnce(
             "Too many requests at once. Please try again in few seconds."
         )
